@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
 
-   Copyright (c) 2000,2001 Dawit Alemayehu <adawit@kde.org>
-   Copyright (c) 2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License (LGPL) as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef KCOMBOBOX_H
@@ -48,7 +36,7 @@ class QMenu;
  *   @li a popup menu item that can be used to allow the user to change
  * the text completion mode on the fly.
  *
- * To support these new features, KComboBox emits a few additional signals
+ * To support these additional features, KComboBox emits a few additional signals
  * such as completion(const QString&) and textRotation(KeyBindingType).
  * The completion signal can be connected to a slot that will assist the user in
  * filling out the remaining text while the rotation signal can be used to traverse
@@ -365,14 +353,13 @@ public:
     bool trapReturnKey() const;
 
     /**
-     * @returns the completion box that is used in completion mode
-     * CompletionPopup and CompletionPopupAuto.
-     *
      * This method will create a completion box by calling
      * KLineEdit::completionBox, if none is there yet.
      *
      * @param create Set this to false if you don't want the box to be created
      *               i.e. to test if it is available.
+     * @returns the completion box that is used in completion mode
+     * CompletionPopup and CompletionPopupAuto.
      */
     KCompletionBox *completionBox(bool create = true);
 
@@ -396,6 +383,14 @@ public:
      */
     void setEditable(bool editable);
 
+    /**
+     * Pointer to KLineEdit's context menu, or nullptr if it does not exist at
+     * the given moment.
+     *
+     * @since 5.78
+     */
+    QMenu *contextMenu() const;
+
 Q_SIGNALS:
     /**
     * Emitted when the user presses the Enter key.
@@ -509,7 +504,7 @@ protected Q_SLOTS:
     /**
     * Completes text according to the completion mode.
     *
-    * Note: this method is not invoked if the completion mode is
+    * @note This method is not invoked if the completion mode is
     * set to @c CompletionNone. Also if the mode is set to @c CompletionShell
     * and multiple matches are found, this method will complete the
     * text to the first match with a beep to indicate that there are
