@@ -1,26 +1,14 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999,2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999, 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kcompletion.h"
 #include "kcompletion_p.h"
+#include <kcompletion_debug.h>
 
-#include <QDebug>
 #include <QCollator>
 
 void KCompletionPrivate::init()
@@ -42,7 +30,7 @@ void KCompletionPrivate::addWeightedItem(const QString &item)
         return;
     }
 
-    uint len = item.length();
+    int len = item.length();
     uint weight = 0;
 
     // find out the weighting of this item (appended to the string as ":num")
@@ -242,7 +230,7 @@ void KCompletion::addItem(const QString &item, uint weight)
     }
 
     KCompTreeNode *node = d->treeRoot;
-    uint len = item.length();
+    int len = item.length();
 
     bool sorted = (d->order == Sorted);
     bool weighted = ((d->order == Weighted) && weight > 1);
@@ -250,7 +238,7 @@ void KCompletion::addItem(const QString &item, uint weight)
     // knowing the weight of an item, we simply add this weight to all of its
     // nodes.
 
-    for (uint i = 0; i < len; i++) {
+    for (int i = 0; i < len; i++) {
         node = node->insert(item.at(i), sorted);
         if (weighted) {
             node->confirm(weight - 1);    // node->insert() sets weighting to 1
@@ -639,7 +627,7 @@ QStringList KCompletionMatchesWrapper::list() const
     } else if (m_compOrder == KCompletion::Sorted) {
         QCollator c;
         c.setCaseSensitivity(Qt::CaseSensitive);
-        qStableSort(m_stringList.begin(), m_stringList.end(), c);
+        std::stable_sort(m_stringList.begin(), m_stringList.end(), c);
     }
 
     return m_stringList;
