@@ -1,44 +1,32 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
 
-   Copyright (C) 1997 Sven Radej (sven.radej@iname.com)
-   Copyright (c) 1999 Patrick Ward <PAT_WARD@HP-USA-om5.om.hp.com>
-   Copyright (c) 1999 Preston Brown <pbrown@kde.org>
+    SPDX-FileCopyrightText: 1997 Sven Radej <sven.radej@iname.com>
+    SPDX-FileCopyrightText: 1999 Patrick Ward <PAT_WARD@HP-USA-om5.om.hp.com>
+    SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
 
-   Re-designed for KDE 2.x by
-   Copyright (c) 2000, 2001 Dawit Alemayehu <adawit@kde.org>
-   Copyright (c) 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    Re-designed for KDE 2.x by
+    SPDX-FileCopyrightText: 2000, 2001 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License (LGPL) as published by the Free Software Foundation;
-   either version 2 of the License, or (at your option) any later
-   version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "klineedit.h"
 #include "klineedit_p.h"
 
-#include <kauthorized.h>
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
-#include <kcursor.h>
+#include <KAuthorized>
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <KCursor>
 #include <kcompletionbox.h>
-#include <kstandardshortcut.h>
+#include <KStandardShortcut>
 #include <lineediturldropeventfilter.h>
 
 #include <QTimer>
 #include <QApplication>
 #include <QClipboard>
+#include <QKeyEvent>
 #include <QMenu>
 #include <QToolTip>
 
@@ -886,7 +874,7 @@ void KLineEdit::mousePressEvent(QMouseEvent *e)
 
     // if middle clicking and if text is present in the clipboard then clear the selection
     // to prepare paste operation
-    if (e->button() == Qt::MidButton) {
+    if (e->button() == Qt::MiddleButton) {
         if (hasSelectedText() && !isReadOnly()) {
             if (QApplication::clipboard()->text(QClipboard::Selection).length() > 0) {
                 backspace();
@@ -933,7 +921,7 @@ QMenu *KLineEdit::createStandardContextMenu()
             separatorAction = actionList.at(idx);
         }
         if (separatorAction) {
-            QAction *clearAllAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-clear")), tr("C&lear"), this);
+            QAction *clearAllAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-clear")), tr("C&lear", "@action:inmenu"), this);
             clearAllAction->setShortcuts(QKeySequence::keyBindings(QKeySequence::DeleteCompleteLine));
             connect(clearAllAction, &QAction::triggered, this, &QLineEdit::clear);
             if (text().isEmpty()) {
@@ -1234,7 +1222,7 @@ bool KLineEditPrivate::overrideShortcut(const QKeyEvent *e)
     // but doesn't dare force as "stronger than kaction shortcuts"...
     else if (e->matches(QKeySequence::SelectAll)) {
         return true;
-    } else if (qApp->platformName() == QLatin1String("xcb") && (key == Qt::CTRL + Qt::Key_E || key == Qt::CTRL + Qt::Key_U)) {
+    } else if (qApp->platformName() == QLatin1String("xcb") && (key == Qt::CTRL | Qt::Key_E || key == Qt::CTRL | Qt::Key_U)) {
         return true;
     }
 
